.. image:: https://rattlesnp.readthedocs.io/en/latest/_images/rattleSNP_logo.png
   :target: https://rattlesnp.readthedocs.io/en/latest/_images/rattleSNP_logo.png
   :align: center
   :alt: RattleSNP Logo

|PythonVersions| |SnakemakeVersions|

.. contents:: Table of Contents
    :depth: 2

About RattleSNP
==================

**Homepage:** `https://rattleSNP.readthedocs.io/en/latest/ <https://rattleSNP.readthedocs.io/en/latest/>`_


The Best snakemake mapping pipeline !!!

Authors
=======

* Sébastien RAVEL(CIRAD).

License
=======
Licencied under `CeCill-C <http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html>`_ and GPLv3.

Intellectual property belongs to CIRAD and authors.

.. |PythonVersions| image:: https://img.shields.io/badge/python-3.7%2B-blue
   :target: https://www.python.org/downloads
.. |SnakemakeVersions| image:: https://img.shields.io/badge/snakemake-≥5.10.0-brightgreen.svg?style=flat
   :target: https://snakemake.readthedocs.io
